#import <Foundation/Foundation.h>
#import "InterruptedException.h"

@interface BlockingInputStream : NSObject {
	NSTimeInterval timeout;
	NSInputStream *is;
	BOOL interrupted;
	NSThread * _readThread;
}

+ (BlockingInputStream*) withStream:(NSInputStream*) is;
+ (BlockingInputStream*) withData:(NSData*) data;

- (BlockingInputStream*) initWithData:(NSData *) data;
- (BlockingInputStream*) initWithIStream:(NSInputStream*) i;

- (NSData*) read:(NSUInteger) len required:(BOOL) required;
- (NSUInteger) read:(uint8_t *)buffer length:(NSUInteger)len required:(BOOL) required;
- (NSData*) readUntil:(NSData*) terminator;  // might be slow on phone
- (NSData*) readFully;
- (void) readBlock:(BasicBlock) reader isFinished:(BOOL (^)()) isFinished;
- (void) close;

/**
 Stop trying to read, causing an InterruptedException to be thrown on the reading thread. The underlying InputStream is closed.
 Can be safely called from any thread.
 Returns whether the thread was actually interrupted (ie. whether a read was in progress). Even if it's not, the next read will be.
 */
- (BOOL) interrupt;

/**
 This timeout means an error gets thrown if no data is read during the specific time. It doesn't mean *all* data must be read in this time, just some, so a read might well take longer than this. This is good for big reads.
 (Could possibly have an "overall timeout" too if we needed it.)
 
 Set to 0 to never time out. Not sure you'll ever want to though.
 */
@property (assign) NSTimeInterval timeout;

@end