
@interface NetworkInterface : NSObject {
	NSString *oid;
	NSDictionary* ipInfo;
	NSDictionary* interfaceInfo;
	NSString *ipAddress;
	NSString *subnetMask;
}
@property (readonly) BOOL active;
@property (readonly, retain, nonatomic) NSString *ipAddress;
@property (readonly, retain, nonatomic) NSString *subnetMask;
@property (readonly) NSString* deviceName;
@property (readonly) NSString* router;
@property (readonly) NSArray* ipAddresses;
@property (readonly) NSArray* subnetMasks;
@property (readonly) BOOL airport;

+ (NSArray*) activeInterfaces;
+ (NSArray*) allInterfaces;

/**
 The first active interface. Cleverly, this seems to work out which one actually gets us to the internet
 */
+ (NetworkInterface*) primaryInterface;
+ (NSString*) primaryIpAddress;
+ (NSString*) routerIpAddress;
+ (NSString*) ipAddressPreferringAirport;

/**
 Returns the Airport interface if there is one and it's active
 */
+ (NetworkInterface*) airportInterface;

/**
 If there is both an Airport interface, different to the primary interface but ON THE SAME SUBNET, returns
 the Airport interface. Otherwise returns the primary interface.
 
 That same subnet bit is important - the idea is to prefer Airport as long as it goes to the same place,
 ie. probably the internet. (Theoretically they could belong to a private wireless network which is different
 from the primary network, which should be the internet one.)
 */
+ (NetworkInterface*) airportOrPrimary;


/**
 Returns the first interface on the same subnet, otherwise nil.
 */
+ (NetworkInterface*) interfaceOnSameSubnetAsIp:(NSString*) ip;
+ (NetworkInterface*) interfaceOnSameSubnetAsHost:(NSHost*) host;

/**
 The first interface on the same subnet, otherwise the primary interface.
 */
+ (NetworkInterface*) interfaceForAccessingIp:(NSString*) ip;
+ (NetworkInterface*) interfaceForAccessingHost:(NSHost*) host;

- (BOOL) isOnSameSubnetAsIp:(NSString*) ip;
- (BOOL) isOnSameSubnetAsHost:(NSHost*) host;


@end
